@@ -5,7 +5,7 @@ use 5.10.0;
 use strict;
 use warnings;
 
-our $VERSION = '0.01'; # TRIAL
+our $VERSION = '0.02'; # TRIAL
 
 use Carp;
 our @CARP_NOT = qw( Beam::Emitter );
@@ -507,66 +507,71 @@ Net::Object::Peer - Peer-to-Peer Publish/Subscribe Network of Objects
 
 =head1 VERSION
 
-version 0.01
+version 0.02
 
 =head1 SYNOPSIS
 
  use 5.10.0;
  
- package Node {
-    use Moo;
-    with 'Net::Object::Peer';
+ package Node;
+ use Moo;
+ with 'Net::Object::Peer';
  
-    has name => is => ( 'ro', required => 1 );
+ has name => is => ( 'ro', required => 1 );
  
-    sub _notify_subscribed {
- 
-      my ( $self, $peer, $name ) = @_;
- 
-      say $self->name, ":\tpeer (@{[ $peer->name ]}) subscribed to event $name";
- 
-    }
- 
-    sub _cb_changed {
- 
-        my ( $self, $event ) = @_;
- 
-        say $self->name, ":\tpeer (@{[ $event->emitter->name ]}) changed";
- 
-    }
- 
-    sub _cb_unsubscribe {
- 
-        my ( $self, $event ) = @_;
- 
- 	say $self->name, ":\tpeer (@{[ $event->emitter->name ]}) unsubscribed";
-    }
+ sub _notify_subscribed {
+     my ( $self, $peer, $name ) = @_;
+     say $self->name, ":\t@{[ $peer->name ]} subscribed to event $name";
  }
  
+ sub _cb_hey {
+     my ( $self, $event ) = @_;
+     say $self->name,
+       ":\t@{[ $event->emitter->name ]} sent @{[$event->name]}";
+ }
+ 
+ sub _cb_unsubscribe {
+     my ( $self, $event ) = @_;
+     say $self->name, ":\t@{[ $event->emitter->name ]} unsubscribed";
+ }
+ 
+ package main;
+ 
  
  my $n1 = Node->new( name => 'N1' );
  my $n2 = Node->new( name => 'N2' );
+ my $n3 = Node->new( name => 'N3' );
  
- # n1 will follow n2's changes
- $n1->subscribe( $n2, 'changed' );
+ # Net::Object::Peer provides an "unsubscribe" event; $n1 will be
+ # notified when $n2 unsubscribes from it
+ $n1->subscribe( $n2, 'unsubscribe' );
  
- # n2 will notice if n1 is unsubscribed from it
- $n2->subscribe( $n1, 'unsubscribe' );
+ # $n2 and $n3 will be notified when $n1 sends a "hey" event, and $n1
+ # will be notified that they have subscribed 
  
- $n2->emit( 'changed' );
+ $n2->subscribe( $n1, 'hey' );
+ $n3->subscribe( $n1, 'hey' );
  
- # destroy n1; n1 will unsubscribe and n2 will be notified 
- undef $n1;
+ # both $n2 and $n3 will get notified
+ $n1->emit( 'hey' );
+ 
+ # only $n2 gets notified
+ $n1->send( $n2, 'hey' );
+ 
+ # destroy $n2; $n2 will unsubscribe from all of its events and $n1
+ # will be notified that $n2 has unsubscribed from it.
+ undef $n2;
 
 Resulting in:
 
-  N2:	peer (N2) subscribed to event changed
-  N1:	peer (N1) subscribed to event unsubscribed
-  N1:	peer (N2) changed
-  N2:	unsubscribing from all peers
-  N2:	notifying all subscribed peers of unsubscription
-  N1:	unsubscribing from all peers
-  N1:	notifying all subscribed peers of unsubscription
+ N2:	N1 subscribed to event unsubscribe
+ N1:	N2 subscribed to event hey
+ N1:	N3 subscribed to event hey
+ N2:	N1 sent hey
+ N3:	N1 sent hey
+ N2:	N1 sent hey
+ N1:	N2 unsubscribed
+
 
 =head1 DESCRIPTION
 
@@ -607,7 +612,7 @@ L</emit> or L</send> methods,
 
   $emitter->emit( $event_name );
 
- the event handler will be invoked as
+the event handler will be invoked as
 
   $subscriber->method( $event );
 
@@ -801,14 +806,7 @@ __END__
 #pod
 #pod Resulting in:
 #pod
-#pod   N2:	peer (N2) subscribed to event changed
-#pod   N1:	peer (N1) subscribed to event unsubscribed
-#pod   N1:	peer (N2) changed
-#pod   N2:	unsubscribing from all peers
-#pod   N2:	notifying all subscribed peers of unsubscription
-#pod   N1:	unsubscribing from all peers
-#pod   N1:	notifying all subscribed peers of unsubscription
-#pod
+#pod # COMMAND: perl -Ilib examples/synopsis.pl
 #pod
 #pod =head1 DESCRIPTION
 #pod
@@ -850,7 +848,7 @@ __END__
 #pod
 #pod   $emitter->emit( $event_name );
 #pod
-#pod  the event handler will be invoked as
+#pod the event handler will be invoked as
 #pod
 #pod   $subscriber->method( $event );
 #pod
